sample_test_with_naarad_run_tests_in_parallel_20141211_225711

### sample_config2

Total tests | Passed | Failed | Skipped | Execution time | Naarad
--- | --- | --- | --- | --- | ---
0 | 0 | 0 | 0 | 0.00582003593445 sec | Report

Messages: setup_suite() failed. See below for the trace. Traceback (most recent call last): File "/home/jehrlich/workspace/zopkio/zopkio/test_runner.py", line 105, in run self.deployment_module.setup_suite() File "/home/jehrlich/workspace/zopkio/test/samples/sample_test_with_naarad_run_tests_in_parallel.py", line 44, in setup_suite shutil.rmtree("/tmp/test_with_naarad") File "/usr/lib64/python2.6/shutil.py", line 212, in rmtree rmtree(fullname, ignore_errors, onerror) File "/usr/lib64/python2.6/shutil.py", line 221, in rmtree onerror(os.rmdir, path, sys.exc_info()) File "/usr/lib64/python2.6/shutil.py", line 219, in rmtree os.rmdir(path) OSError: [Errno 13] Permission denied: '/tmp/test_with_naarad/results'